.. _topology:

Topology
********

Algorithms for the analysis of graph topology.

Structure
---------

.. autofunction:: sknetwork.topology.connected_components

.. autofunction:: sknetwork.topology.largest_connected_component

.. autoclass:: sknetwork.topology.CoreDecomposition

.. autofunction:: sknetwork.topology.is_bipartite

.. autofunction:: sknetwork.topology.is_acyclic

.. autoclass:: sknetwork.topology.DAG

Counting
--------

.. autoclass:: sknetwork.topology.Triangles

.. autoclass:: sknetwork.topology.Cliques

Coloring
--------

.. autoclass:: sknetwork.topology.WeisfeilerLehman

Similarity
----------

.. autofunction:: sknetwork.topology.are_isomorphic
